@@ -4,6 +4,7 @@ import math
 import textwrap
 import os
 import webbrowser
+import warnings
 
 
 def _interactive_display(filename):
@@ -155,13 +156,13 @@ def _tm2pretty_string(x_tick, max_t_trunc, min_t_trunc, n_ticks, isfirst):
         x_out = str(x_tick).split(' ')[0]
     elif min_t_trunc == 'year':
         x_out = str(x_tick.year)
-    elif min_t_trunc == 'month' and max_t_trunc=='year':
+    elif min_t_trunc == 'month' and max_t_trunc == 'year':
         x_out = str(x_tick.year) + '-' + str(x_tick.month)
-    elif min_t_trunc == 'month' and max_t_trunc=='month':
+    elif min_t_trunc == 'month' and max_t_trunc == 'month':
         x_out = x_tick.strftime("%B")[:3]
         if isfirst:
             x_out = str(x_tick.year) + '-' + x_tick.strftime("%B")[:3]
-    elif min_t_trunc =='day':
+    elif min_t_trunc == 'day':
         x_out = str(x_tick).split(' ')[0]
     elif max_t_trunc in ('hour', 'minute', 'second', 'msecond'):
         x_out = str(x_tick).split(' ')[1]
@@ -224,28 +225,43 @@ def _convert_to_lists_of_lists(xs, ys, yus, yls):
     return xs, ys, yus, yls
 
 
-def _convert_colors(colors, fill_colors, fill_opacities, ys, yus):
+def _convert_colors(colors, fill_colors, fill_opacities, ys, yus, CLR,
+                    dark_mode):
     if colors is None:
-        colors = ['black', 'blue', 'red', 'green', 'orange', 'violet', 'brown']
+        colors = [CLR, 'blue', 'red', 'green', 'orange', 'violet', 'brown']
         if len(ys) > len(colors):
-            num_colors = len(ys)
-            colors = []
-            for color_ind in range(num_colors):
-                red = math.floor(min(255, color_ind*256*2/num_colors))
-                green = math.floor(max(0, color_ind*256*2/num_colors - 256))
-                this_color = 'rgb(' + str(red) + ', ' + str(green) + ', 0)'
-                colors.append(this_color)
+            if dark_mode:
+                num_colors = len(ys)
+                colors = []
+                for color_ind in range(num_colors):
+                    blu = math.floor(min(255, color_ind*256*2/num_colors))
+                    blu = 255 - blu
+                    grn = math.floor(max(0, color_ind*256*2/num_colors - 256))
+                    grn = 255 - grn
+                    this_clr = 'rgb(255, ' + str(grn) + ', ' + str(blu) + ')'
+                    colors.append(this_clr)
+            else:
+                num_colors = len(ys)
+                colors = []
+                for color_ind in range(num_colors):
+                    red = math.floor(min(255, color_ind*256*2/num_colors))
+                    grn = math.floor(max(0, color_ind*256*2/num_colors - 256))
+                    this_color = 'rgb(' + str(red) + ', ' + str(grn) + ', 0)'
+                    colors.append(this_color)
     if fill_colors is None:
         fill_colors = colors.copy()
 
     if (fill_opacities is None) and (yus is not None):
-        fill_opacities = ['0.2']*len(yus)
+        if dark_mode:
+            fill_opacities = ['0.4']*len(yus)
+        else:
+            fill_opacities = ['0.2']*len(yus)
 
     return colors, fill_colors, fill_opacities
 
 
 def _make_x_axis(x_ticks, x_ticks_text, x_label, vb_width, vb_height, YBUF,
-                 tick_length, x2vb):
+                 tick_length, x2vb, CLR):
     if len(x_ticks) < 2:
         x_axis = ''
         x_axis_text_vb = ''
@@ -265,19 +281,19 @@ def _make_x_axis(x_ticks, x_ticks_text, x_label, vb_width, vb_height, YBUF,
                 {xtn_vb},{x_axis_y_vb}""") + ' '
             x_axis_text_vb += '\n    '
             x_axis_text_vb += _remove_extra_whitespace(f"""\
-                <text x="{xt_vb}" y="{x_axis_y_vb + tick_length}" fill="black"
+                <text x="{xt_vb}" y="{x_axis_y_vb + tick_length}" fill="{CLR}"
                 text-anchor="middle" dominant-baseline="hanging" > {xt_text}
                 </text>""")
 
         x_axis_pts_vb += f""" {xtn_vb},{x_axis_yt_vb}"""
         x_axis_text_vb += '\n    '
         x_axis_text_vb += _remove_extra_whitespace(f"""\
-            <text x="{xtn_vb}" y="{x_axis_y_vb + tick_length}" fill="black"
+            <text x="{xtn_vb}" y="{x_axis_y_vb + tick_length}" fill="{CLR}"
             text-anchor="middle" dominant-baseline="hanging" >
             {x_ticks_text[-1]} </text> </g>""")
 
         x_axis = _remove_extra_whitespace(f"""\
-            <polyline fill="none" stroke="black" stroke-width="1"
+            <polyline fill="none" stroke="{CLR}" stroke-width="1"
             points="{x_axis_pts_vb}" />""")
 
     if x_label is None:
@@ -287,7 +303,7 @@ def _make_x_axis(x_ticks, x_ticks_text, x_label, vb_width, vb_height, YBUF,
         x_label_y_vb = vb_height - tick_length
 
         x_axis_label = _remove_extra_whitespace(f"""\
-            <text x="{x_label_x_vb}" y="{x_label_y_vb}" fill="black"
+            <text x="{x_label_x_vb}" y="{x_label_y_vb}" fill="{CLR}"
             text-anchor="middle" font-family="sans-serif" font-size="10">
             {x_label} </text>""")
 
@@ -328,6 +344,8 @@ def _make_lines_and_labels(xs, ys, x2vb, y2vb, colors, labels, label_nudges,
         if points_radii is not None:
             c_r = points_radii[line_ind % len(points_radii)]
             polylines += all_circles[line_ind].format(cr=c_r, cc=color) + '\n'
+        else:
+            c_r = 0
         if labels is not None:
             label = labels[line_ind]
             label_nudge = -1*label_nudges[line_ind]
@@ -337,7 +355,7 @@ def _make_lines_and_labels(xs, ys, x2vb, y2vb, colors, labels, label_nudges,
             y_label_vb = y2vb(ys[line_ind][max_ind])
             line_labels += '\n    '
             line_labels += _remove_extra_whitespace(f"""\
-                <text x="{x_label_vb + tick_length}"
+                <text x="{x_label_vb + tick_length + c_r}"
                 y="{y_label_vb}" dy="{label_nudge}" fill="{label_color}"
                 dominant-baseline="middle">{label}</text>""")
 
@@ -377,7 +395,7 @@ def _make_polygons(xs, yus, yls, x2vb, y2vb, fill_colors, fill_opacities):
 
 
 def _make_y_axis(y_ticks, y_ticks_text, y_label, vb_width, vb_height, XBUF,
-                 tick_length, y2vb):
+                 tick_length, y2vb, CLR):
 
     if len(y_ticks) < 2:
         y_axis = ''
@@ -398,17 +416,17 @@ def _make_y_axis(y_ticks, y_ticks_text, y_label, vb_width, vb_height, XBUF,
                 {y_axis_x_vb},{ytn_vb}""") + ' '
             y_axis_text_vb += '\n    '
             y_axis_text_vb += _remove_extra_whitespace(f"""\
-                <text x="{y_axis_x_vb - tick_length}" y="{yt_vb}" fill="black"
+                <text x="{y_axis_x_vb - tick_length}" y="{yt_vb}" fill="{CLR}"
                 text-anchor="end" dominant-baseline="middle" > {yt_text}
                 </text>""")
 
         y_axis_pts_vb += f"""{y_axis_xt_vb},{ytn_vb}"""
         y_axis_text_vb += _remove_extra_whitespace(f"""\
-            <text x="{y_axis_x_vb - tick_length}" y="{ ytn_vb}" fill="black"
+            <text x="{y_axis_x_vb - tick_length}" y="{ ytn_vb}" fill="{CLR}"
             text-anchor="end" dominant-baseline="middle" > {y_ticks_text[-1]}
             </text> </g>""")
         y_axis = _remove_extra_whitespace(f"""\
-            <polyline fill="none" stroke="black" stroke-width="1"
+            <polyline fill="none" stroke="{CLR}" stroke-width="1"
             points="{y_axis_pts_vb}" />""")
 
     if y_label is None:
@@ -417,21 +435,21 @@ def _make_y_axis(y_ticks, y_ticks_text, y_label, vb_width, vb_height, XBUF,
         y_label_x_vb = tick_length
         y_label_y_vb = .5 * vb_height
         y_axis_label = _remove_extra_whitespace(f"""\
-            <text fill="black" text-anchor="middle" dominant-baseline="hanging"
+            <text fill="{CLR}" text-anchor="middle" dominant-baseline="hanging"
             transform="translate({y_label_x_vb},{y_label_y_vb}) rotate(270)"
             font-family="sans-serif" font-size="10"> {y_label} </text>""")
 
     return y_axis, y_axis_text_vb, y_axis_label
 
 
-def _make_title(title, vb_width, tick_length):
+def _make_title(title, vb_width, tick_length, CLR):
     if title is None:
         title_vb = ''
     else:
         title_x_vb = .5*vb_width
         title_y_vb = tick_length
         title_vb = _remove_extra_whitespace(f"""\
-            <text x="{title_x_vb}" y="{title_y_vb}" fill="black"
+            <text x="{title_x_vb}" y="{title_y_vb}" fill="{CLR}"
             text-anchor="middle" dominant-baseline="hanging"
             font-family="sans-serif" font-size="10"> {title} </text>""")
     return title_vb
@@ -442,14 +460,23 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
               colors=None, fill_colors=None, fill_opacities=None,
               line_widths='1', points_radii=None,
               labels=None, label_nudges=None,
-              x_ticks=None, y_ticks=None, x_ticks_text=None,
-              interactive_mode=True):
+              x_ticks=None, y_ticks=None,
+              x_ticks_text=None, y_ticks_text=None,
+              interactive_mode=True, dark_mode=False):
     if filename[-4:] != '.svg':
         filename += '.svg'
 
     if x_ticks_text is not None:
-        assert x_ticks is not None, 'x_ticks_text requies x_ticks'
-        assert len(x_ticks) == len(x_ticks_text), 'x_ticks x_ticks_text '
+        if x_ticks is None:
+            warnings.warn('x_ticks_text requires x_ticks')
+        elif len(x_ticks) != len(x_ticks_text):
+            warnings.warn('#x_ticks != #x_ticks_text')
+
+    if y_ticks_text is not None:
+        if y_ticks is None:
+            warnings.warn('y_ticks_text requires y_ticks')
+        elif len(y_ticks) != len(y_ticks_text):
+            warnings.warn('#y_ticks != #y_ticks_text')
 
     XBUF = 0.1
     YBUF = 0.13
@@ -460,6 +487,11 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
     vb_width_in = vb_width*.0096*2
     vb_height_in = vb_height*.0096*2
 
+    if dark_mode:
+        CLR = 'white'
+    else:
+        CLR = 'black'
+
     if label_nudges is None and labels is not None:
         label_nudges = [0 for y in ys]
 
@@ -515,7 +547,7 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
         if x_ticks_text is None:
             max_t_trunc, min_t_trunc = find_safe_time_trunc(x_ticks)
             x_ticks_text = [_tm2pretty_string(_xt, max_t_trunc, min_t_trunc,
-                                              len(x_ticks), _xt==x_ticks[0])
+                                              len(x_ticks), _xt == x_ticks[0])
                             for _xt in x_ticks]
         # trying to convert ticks
         x_ticks = [datetime.timestamp(_xt) for _xt in x_ticks]
@@ -528,7 +560,7 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
 
     colors, fill_colors, fill_opacities = _convert_colors(colors, fill_colors,
                                                           fill_opacities, ys,
-                                                          yus)
+                                                          yus, CLR, dark_mode)
 
     x_range = x_max - x_min
     if x_range == 0:
@@ -558,13 +590,16 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
     x_axis, x_axis_text_vb, x_axis_label = _make_x_axis(x_ticks, x_ticks_text,
                                                         x_label, vb_width,
                                                         vb_height, YBUF,
-                                                        tick_length, x2vb)
-    y_ticks_text = [_num2pretty_string(_yt) for _yt in y_ticks]
+                                                        tick_length, x2vb,
+                                                        CLR)
+    if y_ticks_text is None:
+        y_ticks_text = [_num2pretty_string(_yt) for _yt in y_ticks]
     y_axis, y_axis_text_vb, y_axis_label = _make_y_axis(y_ticks, y_ticks_text,
                                                         y_label, vb_width,
                                                         vb_height, XBUF,
-                                                        tick_length, y2vb)
-    title_vb = _make_title(title, vb_width, tick_length)
+                                                        tick_length, y2vb,
+                                                        CLR)
+    title_vb = _make_title(title, vb_width, tick_length, CLR)
 
     full_figure = textwrap.shorten(f"""\
     <?xml version="1.0" standalone="no"?>
@@ -573,6 +608,9 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
     viewBox="0 0 {vb_width} {vb_height}"
     xmlns="http://www.w3.org/2000/svg" version="1.1">""", 1000)
 
+    if dark_mode:
+        full_figure += '\n<rect width="100%" height="100%" fill="#000000"/>'
+
     full_figure += f'\n{polygons}\n{polylines}\n{line_labels}\n'
     full_figure += f'{x_axis}\n{x_axis_text_vb}\n{x_axis_label}\n'
     full_figure += f'{y_axis}\n{y_axis_text_vb}\n{y_axis_label}\n'
@@ -620,14 +658,20 @@ def plot(*args, **kwargs):
         distances to move labels (intended to manually avoid overlaps)
     x_ticks : list, optional
         locations of ticks on the x-axis.
-        Empty (or length 1 list) will result in no x-axis being displayed.
-        If None a automatically generated axis is displayed
+        If list with one element, will result in no x-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
     y_ticks : list, optional
         locations of ticks on the y-axis.
-        Empty (or length 1 list) will result in no y-axis being displayed.
-        If None a automatically generated axis is displayed
+        If list with one element, will result in no y-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    x_ticks_text : list, optional
+        text to replace x_tick labels (requires x_ticks)
+    y_ticks_text : list, optional
+        text to replace y_tick labels (requires y_ticks)
     interactive_mode : bool, optional
-        if True, display inline (jupyter notebooks) or in new browser tab.
+        if True, display inline (jupyter notebooks) or in new browser tab
 
     Returns
     -------
@@ -683,12 +727,20 @@ def scatter(*args, **kwargs):
         distances to move labels (intended to manually avoid overlaps)
     x_ticks : list, optional
         locations of ticks on the x-axis.
-        Empty (or length 1 list) will result in no x-axis being displayed.
-        If None a automatically generated axis is displayed
+        If list with one element, will result in no x-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
     y_ticks : list, optional
         locations of ticks on the y-axis.
-        Empty (or length 1 list) will result in no y-axis being displayed.
-        If None a automatically generated axis is displayed
+        If list with one element, will result in no y-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    x_ticks_text : list, optional
+        text to replace x_tick labels (requires x_ticks)
+    y_ticks_text : list, optional
+        text to replace y_tick labels (requires y_ticks)
+    interactive_mode : bool, optional
+        if True, display inline (jupyter notebooks) or in new browser tab
 
     Returns
     -------
@@ -765,12 +817,20 @@ def error_plot(*args, **kwargs):
         distances to move labels (intended to manually avoid overlaps)
     x_ticks : list, optional
         locations of ticks on the x-axis.
-        Empty (or length 1 list) will result in no x-axis being displayed.
-        If None a automatically generated axis is displayed
+        If list with one element, will result in no x-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
     y_ticks : list, optional
         locations of ticks on the y-axis.
-        Empty (or length 1 list) will result in no y-axis being displayed.
-        If None a automatically generated axis is displayed
+        If list with one element, will result in no y-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    x_ticks_text : list, optional
+        text to replace x_tick labels (requires x_ticks)
+    y_ticks_text : list, optional
+        text to replace y_tick labels (requires y_ticks)
+    interactive_mode : bool, optional
+        if True, display inline (jupyter notebooks) or in new browser tab
 
     Returns
     -------
@@ -805,45 +865,53 @@ def error_plot(*args, **kwargs):
 
 def hist(data, bin_edges=10, **kwargs):
     """Returns .svg text and saves a .svg file containing a histogram of the
-        data in list of lists data.
+    data in list of lists data.
 
-        Parameters
-        ----------
-        data : list of lists
-            raw values to be binned into histogram counts
-            (each list corresponds to a different histogram)
-        bin_edges : int or list of lists
-            if int, that number of equally spaced bins are created between the
-            minimum value in the data and the maximum value in data
-            if lists, each list is used as bins for each list in the input data
-        filename : string, optional
-            Name of the file to save. Default is 'plot.svg'
-        x_label : string, optional
-            Label for x axis
-        y_label : string, optional
-            Label for y axis
-        title : string, optional
-            Title of figure
-        colors : list, optional
-            List containing svg colors for each histogram
-        fill_colors : list, optional
-            List containing svg fill colors for each patch
-        fill_opacities : list, optional
-            List containing numbers between 0 and 1 for each fill
-        line_widths : list, optional
-            List containing width for each histogram
-        labels : list of strings, optional
-            Labels corresponding to each line
-        label_nudges : list of ints, optional
-            distances to move labels (intended to manually avoid overlaps)
-        x_ticks : list, optional
-            locations of ticks on the x-axis.
-            Empty (or length 1 list) will result in no x-axis being displayed.
-            If None a automatically generated axis is displayed
-        y_ticks : list, optional
-            locations of ticks on the y-axis.
-            Empty (or length 1 list) will result in no y-axis being displayed.
-            If None a automatically generated axis is displayed
+    Parameters
+    ----------
+    data : list of lists
+        raw values to be binned into histogram counts
+        (each list corresponds to a different histogram)
+    bin_edges : int or list of lists
+        if int, that number of equally spaced bins are created between the
+        minimum value in the data and the maximum value in data
+        if lists, each list is used as bins for each list in the input data
+    filename : string, optional
+        Name of the file to save. Default is 'plot.svg'
+    x_label : string, optional
+        Label for x axis
+    y_label : string, optional
+        Label for y axis
+    title : string, optional
+        Title of figure
+    colors : list, optional
+        List containing svg colors for each histogram
+    fill_colors : list, optional
+        List containing svg fill colors for each patch
+    fill_opacities : list, optional
+        List containing numbers between 0 and 1 for each fill
+    line_widths : list, optional
+        List containing width for each histogram
+    labels : list of strings, optional
+        Labels corresponding to each line
+    label_nudges : list of ints, optional
+        distances to move labels (intended to manually avoid overlaps)
+    x_ticks : list, optional
+        locations of ticks on the x-axis.
+        If list with one element, will result in no x-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    y_ticks : list, optional
+        locations of ticks on the y-axis.
+        If list with one element, will result in no y-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    x_ticks_text : list, optional
+        text to replace x_tick labels (requires x_ticks)
+    y_ticks_text : list, optional
+        text to replace y_tick labels (requires y_ticks)
+    interactive_mode : bool, optional
+        if True, display inline (jupyter notebooks) or in new browser tab
 
         Returns
         -------
@@ -902,7 +970,52 @@ def _make_histogram_xys(hist_data, bin_edges):
 
 
 def bar(*args, bar_width=None, **kwargs):
-    """testing
+    """Returns .svg text and saves a .svg file containing a bar chart of the
+    data in lists xs and ys.
+
+    Parameters
+    ----------
+    xs : list of lists, optional
+        Abscissas of the centers of the bars to plot
+        (each list corresponds to a different collection of bars)
+        if not specified, bars are centered on 0, 1, ... N
+    ys : list of lists
+        Ordinates of the bars to plot
+        (each list corresponds to a different collection)
+    filename : string, optional
+        Name of the file to save. Default is 'plot.svg'
+    x_label : string, optional
+        Label for x axis
+    y_label : string, optional
+        Label for y axis
+    title : string, optional
+        Title of figure
+    colors : list, optional
+        List containing svg colors for each line
+    x_ticks : list, optional
+        locations of ticks on the x-axis.
+        If list with one element, will result in no x-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    y_ticks : list, optional
+        locations of ticks on the y-axis.
+        If list with one element, will result in no y-axis being displayed
+        (but axis will be extended if necessary to include that value)
+        If None an automatically generated axis is displayed
+    x_ticks_text : list, optional
+        text to replace x_tick labels (requires x_ticks)
+    y_ticks_text : list, optional
+        text to replace y_tick labels (requires y_ticks)
+    interactive_mode : bool, optional
+        if True, display inline (jupyter notebooks) or in new browser tab
+
+    Returns
+    -------
+    full_figure : raw svg string
+
+    Notes
+    -----
+    Tries to infer correct behavior when input is unexpected.
 
     """
     if len(args) == 1:
